*==============================================================================*
*                              Description of dofile                           *
/*=============================================================================*
This dofile generates Figures 1, 2, and 3, and Tables 2 and 3 that are presented in 
the comment "Does Diversity Pay? A Replication of Herring (2009)." 
The structure of this dofile is as follows:
  
  1. Setting paths and installing ado-files
  2. Opening data
  3. Skewed variables (Figure 1, Table 2)
  4. Replication results (Table 3, Figure 3)
  5. Violation of OLS assumptions (Figure 2)
  6. Additional robustness checks


*==============================================================================*/
*  	  	 		 1. Setting paths and installing ado-files      	           *
*==============================================================================*

** -- A. Downloading ado-files -- **
ssc install coefplot, replace
ssc install extremes, replace
ssc install estout, replace
ssc install lmnad, replace

** -- B. Setting paths -- **
global dir "SET YOUR PATH"

global pathd "$dir/data"
global pathp "$dir/posted"
global patht "$dir/tables"
global pathf "$dir/figures"
global pathl "$dir/logfiles"

set more off
cap log close
log using "$pathl/analyses_main.log", replace

*==============================================================================*/
*    	   	  	 			 2. Opening the data       			               *
*==============================================================================*
use "$pathp/nos_workingdata.dta", clear

*==============================================================================*
*                               3. Skewed variables                            *
*==============================================================================*

/*Figure 1. Distributions of the Skewed Count Variables Before and After Logging*/

	
	//normalizing count variables by taking the natural log of three variables
	gen co=ln(company_size)
	la var co "Company size (natural logarithm)"
	
	gen es=ln(establishment_size)
	la var es "Establishment size (natural logarithm)"
	
	gen cu=ln(customers)
	la var cu "Customers (natural logarithm)" 
	
	//saving the data for Figure 1 as in article, made in R
	preserve
		keep company_size establishment_size customers co es cu
		saveold "$pathf/Figure1.dta", replace version(12)
	restore
	
	//Figure 1 in Stata
	histogram customers if forprofit==1, frequency normal 
	tempfile fig1a
	graph save "`fig1a'"
		
	histogram cu if forprofit==1, frequency normal 
	tempfile fig1b
	graph save "`fig1b'"
		
	histogram establishment_size if forprofit==1, frequency normal 
	tempfile fig1c
	graph save "`fig1c'"
		
	histogram es if forprofit==1, frequency normal 
	tempfile fig1d
	graph save "`fig1d'"
		
	histogram company_size if forprofit==1, frequency normal 
	tempfile fig1e
	graph save "`fig1e'"
	
	histogram co if forprofit==1, frequency normal 
	tempfile fig1f
	graph save "`fig1f'"
		
	/*graph combine "`fig1a'" ///
					"`fig1b'" ///
					"`fig1c'" ///
					"`fig1d'" ///
					"`fig1e'" ///
					"`fig1f'",  ///
					xsize(6) ysize(6) graphregion(fcolor(white)) iscale(0.4) rows(3)
	graph export "$pathf/Figure1.pdf", replace*/
	
	/*Table 2. Pairwise Correlations with Untransformed and Transformed Measures of Establishment Size and Company Size*/	 
	estpost correlate establishment_size es company_size co aidr aidg sales cu customers market profit, matrix listwise
	esttab using "$patht/Table2.rtf", ///
			unstack replace
				
*==============================================================================*
*                             4. Replication Results                           *
*==============================================================================*

/*Table 3. Effects of Racial and Gender Diversity on Sales, Number of Customers, Market Share and Profitability*/	

	/*SBL 1 (model with correction for sample)*/

		*1. annual sales revenue
		reg sales 	aidr aidg proprietorship partnership public_corporation private_corporation ///
					company_size establishment_size organization_age agriculture mining construction ///
					transportation wholesale retail financialserv businessserv personalserv entertainment ///
					professionalserv northeast midwest south if forprofit==1 
		eststo salesSBL1

		*2. number of customers 
		reg customers 	aidr aidg proprietorship partnership public_corporation private_corporation ///
						company_size establishment_size organization_age agriculture mining construction ///
						transportation wholesale retail financialserv businessserv personalserv entertainment ///
						professionalserv northeast midwest south if forprofit==1 
		eststo customersSBL1

		*3. market share
		reg market 	aidr aidg proprietorship partnership public_corporation private_corporation ///
					company_size establishment_size organization_age agriculture mining construction ///
					transportation wholesale retail financialserv businessserv personalserv entertainment ///
					professionalserv northeast midwest south if forprofit==1 
		eststo marketSBL1

		*4. profitability
		reg profit 	aidr aidg proprietorship partnership public_corporation private_corporation ///
					company_size establishment_size organization_age agriculture mining construction ///
					transportation wholesale retail financialserv businessserv personalserv entertainment ///
					professionalserv northeast midwest south if forprofit==1 
		eststo profitSBL1
		
		
		
	/*SBL 2 (model with correction for sample and skewness)*/

		*1. annual sales revenue

		reg sales 	aidr aidg proprietorship partnership public_corporation private_corporation ///
					co es organization_age  agriculture mining construction ///
					transportation wholesale retail financialserv businessserv personalserv entertainment ///
					professionalserv northeast midwest south if forprofit==1 
		eststo salesSBL2

		*2. number of customers 
		reg cu 	aidr aidg proprietorship partnership public_corporation private_corporation ///
				co es organization_age agriculture mining construction ///
				transportation wholesale retail financialserv businessserv personalserv entertainment ///
				professionalserv northeast midwest south if forprofit==1 
		eststo customersSBL2

		*3. market share
		reg market 	aidr aidg proprietorship partnership public_corporation private_corporation ///
					co es organization_age agriculture mining construction ///
					transportation wholesale retail financialserv businessserv personalserv entertainment ///
					professionalserv northeast midwest south if forprofit==1 
		eststo marketSBL2

		*4. profitability
		reg profit 	aidr aidg proprietorship partnership public_corporation private_corporation ///
					co es organization_age agriculture mining construction ///
					transportation wholesale retail financialserv businessserv personalserv entertainment ///
					professionalserv northeast midwest south if forprofit==1 
		eststo profitSBL2
		
		esttab *
		
	//Table 3
	esttab salesSBL1 customersSBL1 marketSBL1 profitSBL1 salesSBL2 customersSBL2 marketSBL2 profitSBL2 ///
			using "$patht/Table3.rtf", r2 star(* 0.10 ** 0.05 *** 0.01) keep (_cons aidr aidg) ///
			varlabels(_cons "Constant" aidr "Racial Diversity" aidg "Gender Diversity") ///
			order(aidr aidg _cons) addnotes("Source: National Organizations Survey 1996/7, own calculations") replace
	
	est drop *	

	
/*Figure 3. Predicted Effects of Gender Diversity and Racial Diversity on the Four Business Outcomes*/	
	gen depvar=_n

	gen b_r1=.
	gen se_r1=.
	gen b_g1=.
	gen se_g1=.
	gen b_r2=.
	gen se_r2=.
	gen b_g2=.
	gen se_g2=.

	global controls1 proprietorship partnership public_corporation private_corporation ///
		company_size establishment_size organization_age agriculture mining construction ///
		transportation wholesale retail financialserv businessserv personalserv entertainment ///
		professionalserv northeast midwest south

	global controls2 proprietorship partnership public_corporation private_corporation ///
		co es organization_age agriculture mining construction ///
		transportation wholesale retail financialserv businessserv personalserv entertainment ///
		professionalserv northeast midwest south	


	//MODEL WITH CORRECTION FOR SAMPLE ONLY

		*Sales
		reg sales aidr aidg $controls1
		egen std_sales=std(sales) 	if e(sample)==1 //standardize the dependent variable
		egen std_aidr=std(aidr) 	if e(sample)==1 //standardize AID-R
		egen std_aidg=std(aidg) 	if e(sample)==1 //standardize AID-G

		reg std_sales std_aidr std_aidg $controls1 //fully standardized effect sizes
		replace b_r2=_b[std_aidr] 	if  depvar==1
		replace se_r2=_se[std_aidr] if  depvar==1
		replace b_g2=_b[std_aidg] 	if  depvar==1
		replace se_g2=_se[std_aidg] if  depvar==1

		drop std_*
		eststo sales_sample

		*Customers
		reg customers aidr aidg $controls1
		egen std_customers=std(customers) 	if e(sample)==1 //standardize the dependent variable
		egen std_aidr=std(aidr) 			if e(sample)==1 //standardize AID-R
		egen std_aidg=std(aidg)				if e(sample)==1 //standardize AID-G

		reg std_customers std_aidr std_aidg $controls1 //fully standardized effect sizes
		replace b_r2=_b[std_aidr] 	if  depvar==2
		replace se_r2=_se[std_aidr] if  depvar==2
		replace b_g2=_b[std_aidg] 	if  depvar==2
		replace se_g2=_se[std_aidg] if  depvar==2

		drop std_*
		eststo customers_sample

		*Market share
		reg market aidr aidg $controls1
		egen std_market=std(market) if e(sample)==1 //standardize the dependent variable
		egen std_aidr=std(aidr) 	if e(sample)==1 //standardize AID-R
		egen std_aidg=std(aidg) 	if e(sample)==1 //standardize AID-G

		reg std_market std_aidr std_aidg $controls1 //fully standardized effect sizes
		replace b_r2=_b[std_aidr] 	if  depvar==3
		replace se_r2=_se[std_aidr] if  depvar==3
		replace b_g2=_b[std_aidg] 	if  depvar==3
		replace se_g2=_se[std_aidg] if  depvar==3

		drop std_*
		eststo market_sample

		*Profitability
		reg profit aidr aidg $controls1
		egen std_profit=std(profit) if e(sample)==1 //standardize the dependent variable
		egen std_aidr=std(aidr) 	if e(sample)==1 //standardize AID-R
		egen std_aidg=std(aidg) 	if e(sample)==1 //standardize AID-G

		reg std_profit std_aidr std_aidg $controls1 //fully standardized effect sizes
		replace b_r2=_b[std_aidr] 	if  depvar==4
		replace se_r2=_se[std_aidr] if  depvar==4
		replace b_g2=_b[std_aidg] 	if  depvar==4
		replace se_g2=_se[std_aidg] if  depvar==4

		drop std_*
		eststo profit_sample


	//MODEL WITH CORRECTION FOR SAMPLE & SKEWNESS
		*Sales
		reg sales aidr aidg $controls2
		egen std_sales=std(sales) 	if e(sample)==1 //standardize the dependent variable
		egen std_aidr=std(aidr) 	if e(sample)==1 //standardize AID-R
		egen std_aidg=std(aidg) 	if e(sample)==1 //standardize AID-G

		reg std_sales std_aidr std_aidg $controls2 //fully standardized effect sizes
		replace b_r1=_b[std_aidr] 	if  depvar==1
		replace se_r1=_se[std_aidr] if  depvar==1
		replace b_g1=_b[std_aidg] 	if  depvar==1
		replace se_g1=_se[std_aidg] if  depvar==1

		drop std_*
		eststo sales_skew

		*Customers
		reg cu aidr aidg $controls2
		egen std_cu=std(cu) 	if e(sample)==1 //standardize the dependent variable
		egen std_aidr=std(aidr) if e(sample)==1 //standardize AID-R
		egen std_aidg=std(aidg) if e(sample)==1 //standardize AID-G

		reg std_cu std_aidr std_aidg $controls2 //fully standardized effect sizes
		replace b_r1=_b[std_aidr] 	if  depvar==2
		replace se_r1=_se[std_aidr] if  depvar==2
		replace b_g1=_b[std_aidg] 	if  depvar==2
		replace se_g1=_se[std_aidg] if  depvar==2

		drop std_*
		eststo customers_skew

		*Market share
		reg market aidr aidg $controls2
		egen std_market=std(market) if e(sample)==1 //standardize the dependent variable
		egen std_aidr=std(aidr) 	if e(sample)==1 //standardize AID-R
		egen std_aidg=std(aidg) 	if e(sample)==1 //standardize AID-G

		reg std_market std_aidr std_aidg $controls2 //fully standardized effect sizes
		replace b_r1=_b[std_aidr] 	if  depvar==3
		replace se_r1=_se[std_aidr] if  depvar==3
		replace b_g1=_b[std_aidg] 	if  depvar==3
		replace se_g1=_se[std_aidg] if  depvar==3

		drop std_*
		eststo market_skew

		*Profitability
		reg profit aidr aidg $controls2
		egen std_profit=std(profit) if e(sample)==1 //standardize the dependent variable
		egen std_aidr=std(aidr) 	if e(sample)==1 //standardize AID-R
		egen std_aidg=std(aidg) 	if e(sample)==1 //standardize AID-G

		reg std_profit std_aidr std_aidg $controls2 //fully standardized effect sizes
		replace b_r1=_b[std_aidr] 	if  depvar==4
		replace se_r1=_se[std_aidr] if  depvar==4
		replace b_g1=_b[std_aidg] 	if  depvar==4
		replace se_g1=_se[std_aidg] if  depvar==4

		drop std_*
		eststo profit_skew
		
	/*We don't know the standard deviations from Herring's sample and are therefore unable
	to add the coefficients from his 2009 paper. */

	preserve
		keep b_* se_* depvar
		keep if depvar<5

		reshape long b_g b_r se_g se_r, i(depvar) j(model)
		
		gen low_g=b_g-(1.96*se_g)
		gen high_g=b_g+(1.96*se_g)
		gen low_r=b_r-(1.96*se_r)
		gen high_r=b_r+(1.96*se_r)
		
		//saving the data for Figure 3 as in article, made in R
		saveold "$pathf/Figure3.dta", replace version(12)
	 restore
	 
	//Figure 3 in Stata
		coefplot (sales_sample, label(With sample correction)) (sales_skew, label(With skewness correction)), bylabel(Sales) ///
			|| (customers_sample) (customers_skew), bylabel(Customers) ///
			|| (market_sample) (market_skew), bylabel(Market Share) ///
			|| (profit_sample) (profit_skew), bylabel(Profitability) ///
			||, drop(_cons) keep(std_aidg std_aidr) xline(0) 
		
	est drop *

*==============================================================================*
*                        5. Violation of OLS Assumptions                       *
*==============================================================================*

/*Figure 2. Component Plus Residual Plots for Establishment Size and the Four Business Outcomes*/
set scheme s2mono

	*1. annual sales revenue
		//A. Before transformation
		reg sales 	aidr aidg proprietorship partnership public_corporation private_corporation ///
					company_size establishment_size organization_age agriculture mining construction ///
					transportation wholesale retail financialserv businessserv personalserv entertainment ///
					professionalserv northeast midwest south if forprofit==1 
		predict r, res //calculating the residuals
		
		acprplot company_size, lowess title("Sales") ytitle("") xtitle("") graphr(color(white)) xlab(0(100000)320000)  //graphical check for non-linearity and heteroskedasticity (residuals versus IVs plot)
		tempfile fig3a
		graph save "`fig3a'"
		
		acprplot establishment_size, lowess title("Sales") ytitle("") xtitle("") graphr(color(white)) xlab(0(10000)42000)  //idem
		tempfile fig4a
		graph save "`fig4a'"
		
		estat hettest //non-graphical test for heteroskedasticity (Breush-Pagan test)
		estat imtest, white //White's test for heteroskedasticity
		
		qnorm r, title("Sales") ytitle("") xtitle("") graphr(color(white)) //graphical check for non-normality of errors (normal quantile plot)
		tempfile fig5a
		graph save "`fig5a'"
		
		swilk r //non-graphical test for non-normality of errors (Shapiro-Wilk test)
		drop r 
		
		lmnad sales 	aidr aidg proprietorship partnership public_corporation private_corporation ///
					company_size establishment_size organization_age agriculture mining construction ///
					transportation wholesale retail financialserv businessserv personalserv entertainment ///
					professionalserv northeast midwest south if forprofit==1  //Anderson-Darling test

		//B. After transformation
		reg sales 	aidr aidg proprietorship partnership public_corporation private_corporation ///
					co es organization_age agriculture mining construction ///
					transportation wholesale retail financialserv businessserv personalserv entertainment ///
					professionalserv northeast midwest south if forprofit==1 
		
		predict r, res //calculating the residuals
		
		acprplot co, lowess title("Sales") ytitle("") xtitle("") graphr(color(white)) xlab(0(5)13) //graphical check for non-linearity and heteroskedasticity (residuals versus IVs plot)
		tempfile fig3b
		graph save "`fig3b'"
		
		acprplot es, lowess title("Sales") ytitle("") xtitle("") graphr(color(white)) xlab(0(5)12) //idem
		tempfile fig4b
		graph save "`fig4b'"
		
		estat hettest //non-graphical test for heteroskedasticity (Breush-Pagan test)
		estat imtest, white //White's test for heteroskedasticity
		
		qnorm r, title("Sales") ytitle("") xtitle("") graphr(color(white)) //graphical check for non-normality of errors (normal quantile plot)
		tempfile fig5b
		graph save "`fig5b'"
		
		swilk r //non-graphical test for non-normality of errors (Shapiro-Wilk test)
		drop r 
		
		lmnad sales 	aidr aidg proprietorship partnership public_corporation private_corporation ///
					co es organization_age agriculture mining construction ///
					transportation wholesale retail financialserv businessserv personalserv entertainment ///
					professionalserv northeast midwest south if forprofit==1  //Anderson-Darling test

		*2. number of customers 
		//A. Before transformation
		reg cu 	aidr aidg proprietorship partnership public_corporation private_corporation ///
				company_size establishment_size organization_age agriculture mining construction ///
				transportation wholesale retail financialserv businessserv personalserv entertainment ///
				professionalserv northeast midwest south if forprofit==1 
		
		predict r, res //calculating the residuals
		
		acprplot company_size, lowess title("Customers") ytitle("") xtitle("") graphr(color(white)) xlab(0(100000)320000) //graphical check for non-linearity and heteroskedasticity (residuals versus IVs plot)
		tempfile fig3c
		graph save "`fig3c'"
		
		acprplot establishment_size, lowess title ("Customers") ytitle("") xtitle("") graphr(color(white)) xlab(0(10000)42000) //idem
		tempfile fig4c
		graph save "`fig4c'"
		
		estat hettest //non-graphical test for heteroskedasticity (Breush-Pagan test)
		estat imtest, white //White's test for heteroskedasticity
		
		qnorm r, title("Customers") ytitle("") xtitle("") graphr(color(white)) //graphical check for non-normality of errors (normal quantile plot)
		tempfile fig5c
		graph save "`fig5c'"
		
		swilk r //non-graphical test for non-normality of errors (Shapiro-Wilk test)
		drop r 
		
		lmnad cu 	aidr aidg proprietorship partnership public_corporation private_corporation ///
				company_size establishment_size organization_age agriculture mining construction ///
				transportation wholesale retail financialserv businessserv personalserv entertainment ///
				professionalserv northeast midwest south if forprofit==1 //Anderson-Darling test
		
		//B. After transformation
		reg cu 	aidr aidg proprietorship partnership public_corporation private_corporation ///
				co es organization_age agriculture mining construction ///
				transportation wholesale retail financialserv businessserv personalserv entertainment ///
				professionalserv northeast midwest south if forprofit==1 
		
		predict r, res //calculating the residuals
		
		acprplot co, lowess title("Customers") ytitle("") xtitle("") graphr(color(white))  xlab(0(5)13) //graphical check for non-linearity and heteroskedasticity (residuals versus IVs plot)
		tempfile fig3d
		graph save "`fig3d'"
		
		acprplot es, lowess title("Customers") ytitle("") xtitle("") graphr(color(white)) xlab(0(5)12) //idem
		tempfile fig4d
		graph save "`fig4d'"
		
		estat hettest //non-graphical test for heteroskedasticity (Breush-Pagan test)
		estat imtest, white //White's test for heteroskedasticity
		
		qnorm r, title("Customers") ytitle("") xtitle("") graphr(color(white)) //graphical check for non-normality of errors (normal quantile plot)
		tempfile fig5d
		graph save "`fig5d'"
				
		swilk r //non-graphical test for non-normality of errors (Shapiro-Wilk test)
		drop r 
		
		lmnad cu 	aidr aidg proprietorship partnership public_corporation private_corporation ///
				co es organization_age agriculture mining construction ///
				transportation wholesale retail financialserv businessserv personalserv entertainment ///
				professionalserv northeast midwest south if forprofit==1 //Anderson-Darling test

		*3. market share
		//A. Before transformation
		reg market 	aidr aidg proprietorship partnership public_corporation private_corporation ///
					company_size establishment_size organization_age agriculture mining construction ///
					transportation wholesale retail financialserv businessserv personalserv entertainment ///
					professionalserv northeast midwest south if forprofit==1 
		
		predict r, res //calculating the residuals
		
		acprplot company_size, lowess title("Market Share") ytitle("") xtitle("") graphr(color(white)) xlab(0(100000)320000) //graphical check for non-linearity and heteroskedasticity (residuals versus IVs plot)
		tempfile fig3e
		graph save "`fig3e'"
		
		acprplot establishment_size, lowess title("Market Share") ytitle("") xtitle("") graphr(color(white)) xlab(0(10000)42000) //idem
		tempfile fig4e
		graph save "`fig4e'"
		
		estat hettest //non-graphical test for heteroskedasticity (Breush-Pagan test)
		estat imtest, white //White's test for heteroskedasticity
		
		qnorm r, title("Market Share") ytitle("") xtitle("") graphr(color(white)) //graphical check for non-normality of errors (normal quantile plot)
		tempfile fig5e
		graph save "`fig5e'"
				
		swilk r //non-graphical test for non-normality of errors (Shapiro-Wilk test)
		drop r 
		
		lmnad market 	aidr aidg proprietorship partnership public_corporation private_corporation ///
					company_size establishment_size organization_age agriculture mining construction ///
					transportation wholesale retail financialserv businessserv personalserv entertainment ///
					professionalserv northeast midwest south if forprofit==1 //Anderson-Darling test
		
		//B. After transformation
		reg market 	aidr aidg proprietorship partnership public_corporation private_corporation ///
					co es organization_age agriculture mining construction ///
					transportation wholesale retail financialserv businessserv personalserv entertainment ///
					professionalserv northeast midwest south if forprofit==1 
		
		predict r, res //calculating the residuals
		
		acprplot co, lowess title("Market Share") ytitle("") xtitle("") graphr(color(white))  xlab(0(5)13) //graphical check for non-linearity and heteroskedasticity (residuals versus IVs plot)
		tempfile fig3f
		graph save "`fig3f'"
		
		acprplot es, lowess title("Market Share") ytitle("") xtitle("") graphr(color(white)) xlab(0(5)12) //idem
		tempfile fig4f
		graph save "`fig4f'"		
		
		estat hettest //non-graphical test for heteroskedasticity (Breush-Pagan test)
		estat imtest, white //White's test for heteroskedasticity
		
		qnorm r, title("Market Share") ytitle("") xtitle("") graphr(color(white)) //graphical check for non-normality of errors (normal quantile plot)
		tempfile fig5f
		graph save "`fig5f'"
				
		swilk r //non-graphical test for non-normality of errors (Shapiro-Wilk test)
		drop r 
		
		lmnad market 	aidr aidg proprietorship partnership public_corporation private_corporation ///
					co es organization_age agriculture mining construction ///
					transportation wholesale retail financialserv businessserv personalserv entertainment ///
					professionalserv northeast midwest south if forprofit==1 //Anderson-Darling test
		
		*4. profitability
		//A. Before transformation
		reg profit 	aidr aidg proprietorship partnership public_corporation private_corporation ///
					company_size establishment_size organization_age agriculture mining construction ///
					transportation wholesale retail financialserv businessserv personalserv entertainment ///
					professionalserv northeast midwest south if forprofit==1 
		
		predict r, res //calculating the residuals
		
		acprplot company_size, lowess title("Profitability") ytitle("") xtitle("Company size (absolute)", size(medium)) graphr(color(white)) xlabel(0(100000)320000)  //graphical check for non-linearity and heteroskedasticity (residuals versus IVs plot)
		tempfile fig3g
		graph save "`fig3g'"
		
		acprplot establishment_size, lowess title ("Profitability") ytitle("") xtitle("Establishment size (absolute)", size(medium)) graphr(color(white)) xlab(0(10000)42000) //idem
		tempfile fig4g
		graph save "`fig4g'"	
		
		estat hettest //non-graphical test for heteroskedasticity (Breush-Pagan test)
		estat imtest, white //White's test for heteroskedasticity
		
		qnorm r, title("Profitability") ytitle("") xtitle("") graphr(color(white)) //graphical check for non-normality of errors (normal quantile plot)
		tempfile fig5g
		graph save "`fig5g'"
				
		swilk r //non-graphical test for non-normality of errors (Shapiro-Wilk test)
		drop r 
		
		lmnad profit 	aidr aidg proprietorship partnership public_corporation private_corporation ///
					company_size establishment_size organization_age agriculture mining construction ///
					transportation wholesale retail financialserv businessserv personalserv entertainment ///
					professionalserv northeast midwest south if forprofit==1 //Anderson-Darling test

		//B. After transformation
		reg profit 	aidr aidg proprietorship partnership public_corporation private_corporation ///
					co es organization_age agriculture mining construction ///
					transportation wholesale retail financialserv businessserv personalserv entertainment ///
					professionalserv northeast midwest south if forprofit==1 
		
		predict r, res //calculating the residuals
		
		acprplot co, lowess title("Profitability") ytitle("") xtitle("Company size (natural logarithm)", size(medium)) graphr(color(white))  xlab(0(5)13) //graphical check for non-linearity and heteroskedasticity (residuals versus IVs plot)
		tempfile fig3h
		graph save "`fig3h'"
		
		acprplot es, lowess title ("Profitability") ytitle("") xtitle("Establishment size (natural logarithm)", size(medium)) graphr(color(white)) xlab(0(5)12) //idem
		tempfile fig4h
		graph save "`fig4h'"
		
		estat hettest //non-graphical test for heteroskedasticity (Breush-Pagan test)
		estat imtest, white //White's test for heteroskedasticity
		
		qnorm r, title("Profitability") ytitle("") xtitle("") graphr(color(white)) //graphical check for non-normality of errors (normal quantile plot)
		tempfile fig5h
		graph save "`fig5h'"
				
		swilk r //non-graphical test for non-normality of errors (Shapiro-Wilk test)
		drop r 
		
		lmnad profit 	aidr aidg proprietorship partnership public_corporation private_corporation ///
					co es organization_age agriculture mining construction ///
					transportation wholesale retail financialserv businessserv personalserv entertainment ///
					professionalserv northeast midwest south if forprofit==1 //Anderson-Darling test
	
		//Figure 2
		graph combine "`fig4a'" ///
					"`fig4b'" ///
					"`fig4c'" ///
					"`fig4d'" ///
					"`fig4e'" ///
					"`fig4f'" ///
					"`fig4g'" ///
					"`fig4h'", ///
						xsize(6) ysize(8) ///
						title("                Before transformation                             After transformation", position(11) size(small)) /// 
						l1title("Augmented component plus residual", size(small)) ///
						graphregion(color(white)) iscale(0.4) rows(4)
		graph export "$pathf/Figure2.tif", replace width(3000) height(4000)
		
		//Figure 2b. Component Plus Residual Plots for Company Size and the Four Business Outcomes 
		graph combine "`fig3a'" ///
					"`fig3b'" ///
					"`fig3c'" ///
					"`fig3d'" ///
					"`fig3e'" ///
					"`fig3f'" ///
					"`fig3g'" ///
					"`fig3h'", ///
						xsize(6) ysize(8) ///
						l1title("Augmented component plus residual", size(small)) ///
						title("                Before transformation                             After transformation", position(11) size(small)) /// 
						graphregion(color(white)) iscale(0.4) rows(4)
		//graph export "$pathf/Figure2b.pdf", replace
		
		//Figure 2c. Normality of Errors 
		graph combine "`fig5a'" ///
					"`fig5b'" ///
					"`fig5c'" ///
					"`fig5d'" ///
					"`fig5e'" ///
					"`fig5f'" ///
					"`fig5g'" ///
					"`fig5h'", ///
						xsize(6) ysize(8) ///
						title("                Before transformation                             After transformation", position(11) size(small)) /// 
						b1title("Inverse normal", size(small)) ///
						l1title("Residuals", size(small)) ///
						graphregion(color(white)) iscale(0.4) rows(4)
		//graph export "$pathf/Figure2c.pdf", replace
		
		
		
		
		
		
*==============================================================================*
*                        6. Additional Robustness Checks                       *
/*==============================================================================*
A- Dropping businesses with <5 employees
B- Dropping businesses with less than 10 full-time employees
C- Dropping businesses with 0 sales revenue 
D- Dropping businesses with 0 customers
E- Checking normality of all dependent variables
F- Extreme values on count variables
G- Running sales model without top two values on sales
H- Running customers model without top three values on number of customers
I- Checking normality of the predictors of interest (AID-R and AID-G)
J- Rerunning models with different measure of diversity
K- Rerunning models with multiple imputation of missings

*/


//A- Dropping businesses with less than 5 full-time employees
	preserve
		keep if a7_2>5 //146 businesses dropped

		reg sales 	aidr aidg proprietorship partnership public_corporation private_corporation ///
					co es organization_age  agriculture mining construction ///
					transportation wholesale retail financialserv businessserv personalserv entertainment ///
					professionalserv northeast midwest south if forprofit==1 
		eststo //annual sales revenue

		reg cu 	aidr aidg proprietorship partnership public_corporation private_corporation ///
				co es organization_age agriculture mining construction ///
				transportation wholesale retail financialserv businessserv personalserv entertainment ///
				professionalserv northeast midwest south if forprofit==1 
		eststo //number of customers

		reg market 	aidr aidg proprietorship partnership public_corporation private_corporation ///
					co es organization_age agriculture mining construction ///
					transportation wholesale retail financialserv businessserv personalserv entertainment ///
					professionalserv northeast midwest south if forprofit==1 
		eststo //market share

		reg profit 	aidr aidg proprietorship partnership public_corporation private_corporation ///
					co es organization_age agriculture mining construction ///
					transportation wholesale retail financialserv businessserv personalserv entertainment ///
					professionalserv northeast midwest south if forprofit==1 
		eststo //profitability
		
		esttab, star(* 0.10 ** 0.05 *** 0.01)
		est drop *	
		//conclusion: no substantive differences
	restore
	
	
	
//B- Dropping businesses with less than 10 full-time employees
	preserve
		keep if a7_2>10 //211 businesses dropped

		reg sales aidr aidg proprietorship partnership public_corporation private_corporation ///
		co es organization_age  agriculture mining construction ///
		transportation wholesale retail financialserv businessserv personalserv entertainment ///
		professionalserv northeast midwest south if forprofit==1 
		eststo //annual sales revenue

		reg cu aidr aidg proprietorship partnership public_corporation private_corporation ///
		co es organization_age agriculture mining construction ///
		transportation wholesale retail financialserv businessserv personalserv entertainment ///
		professionalserv northeast midwest south if forprofit==1 
		eststo //number of customers

		reg market aidr aidg proprietorship partnership public_corporation private_corporation ///
		co es organization_age agriculture mining construction ///
		transportation wholesale retail financialserv businessserv personalserv entertainment ///
		professionalserv northeast midwest south if forprofit==1 
		eststo //market share

		reg profit aidr aidg proprietorship partnership public_corporation private_corporation ///
		co es organization_age agriculture mining construction ///
		transportation wholesale retail financialserv businessserv personalserv entertainment ///
		professionalserv northeast midwest south if forprofit==1 
		eststo //profitability
		
		esttab, star(* 0.10 ** 0.05 *** 0.01)
		est drop *	
		//conclusion: no substantive differences
	restore	
		
		
		
//C- Dropping businesses with 0 sales revenue 
	preserve
		keep if sales2>0 //8 businesses dropped
		
		reg sales 	aidr aidg proprietorship partnership public_corporation private_corporation ///
					co es organization_age  agriculture mining construction ///
					transportation wholesale retail financialserv businessserv personalserv entertainment ///
					professionalserv northeast midwest south if forprofit==1 
		eststo //annual sales revenue
		esttab, star(* 0.10 ** 0.05 *** 0.01)
		est drop *
		//conclusion: no substantive differences
	restore
	
	
//D- Dropping businesses with 0 customers
	preserve
		keep if customers>0 //5 businesses dropped
	
		reg cu 	aidr aidg proprietorship partnership public_corporation private_corporation ///
				co es organization_age agriculture mining construction ///
				transportation wholesale retail financialserv businessserv personalserv entertainment ///
				professionalserv northeast midwest south if forprofit==1 
		eststo
	
		esttab, star(* 0.10 ** 0.05 *** 0.01)
		est drop *
		//conclusion: no substantive differences
	restore
	
	
//E- Checking normality of all dependent variables
	histogram sales if forprofit==1 & !missing(sales), frequency normal //sales revenue
	histogram cu if forprofit==1 & !missing(cu), frequency normal //number of customers
	histogram market if forprofit==1 & !missing(market), frequency normal //perceived market share
	histogram profit if forprofit==1 & !missing(profit), frequency normal //perceived profitability
	//conclusion: all reasonably normal, after transforming sales and customers.
	
	
//F- Extreme values on count variables
	extremes sales2 //top 2 values
	extremes customers //top 3 values
	extremes company_size //no extreme values
	extremes establishment_size //no extreme values
	extremes organization_age //no extreme values

	
//G- Running sales model without top two values on sales
	preserve
		drop if _n == 472
		drop if _n == 141
		extremes sales2
		
		reg sales 	aidr aidg proprietorship partnership public_corporation private_corporation ///
					co es organization_age  agriculture mining construction ///
					transportation wholesale retail financialserv businessserv personalserv entertainment ///
					professionalserv northeast midwest south if forprofit==1 
		predict r, res //calculating the residuals
		swilk r //non-graphical test for non-normality of errors (Shapiro-Wilk test)
		drop r 
		estat hettest //non-graphical test for heteroskedasticity (Breush-Pagan test)
		
		esttab, star(* 0.10 ** 0.05 *** 0.01) //no substantive differences
		
		lmnad sales 	aidr aidg proprietorship partnership public_corporation private_corporation ///
					co es organization_age  agriculture mining construction ///
					transportation wholesale retail financialserv businessserv personalserv entertainment ///
					professionalserv northeast midwest south if forprofit==1 //Anderson-Darling test				
	restore
	
//H- Running customers model without top three values on number of customers
	preserve
		drop if _n == 883
		drop if _n == 258
		drop if _n == 141
		extremes customers
		
		reg cu 	aidr aidg proprietorship partnership public_corporation private_corporation ///
				co es organization_age agriculture mining construction ///
				transportation wholesale retail financialserv businessserv personalserv entertainment ///
				professionalserv northeast midwest south if forprofit==1
		predict r, res //calculating the residuals
		swilk r //non-graphical test for non-normality of errors (Shapiro-Wilk test)
		drop r 
		estat hettest //non-graphical test for heteroskedasticity (Breush-Pagan test)
				
		esttab, star(* 0.10 ** 0.05 *** 0.01) //no substantive differences
		
		lmnad cu 	aidr aidg proprietorship partnership public_corporation private_corporation ///
				co es organization_age agriculture mining construction ///
				transportation wholesale retail financialserv businessserv personalserv entertainment ///
				professionalserv northeast midwest south if forprofit==1
	restore
	
//I- Checking normality of the predictors of interest (AID-R and AID-G)
	histogram aidr if forprofit==1, frequency normal 
	
	histogram aidg if forprofit==1, frequency normal 
	//conclusion: predictors heavily skewed. 
	
	
	
//J- Rerunning models with different measure of diversity
	/*In I we have shown that the two predictors are heavily skewed. Here we rerun the analyses with a 
	  more common measure of diversity, the HH-index (Herfindahl Hirschman). */
	summ share_white share_male
	gen p_white=share_white/100
	gen p_male=share_male/100
	gen p_nonwhite=1-p_white
	gen p_female=1-p_male
	  
	summ p_*
	  
	gen hhi_race   = 1- ((p_nonwhite^2) + (p_white^2))
	gen hhi_gender = 1- ((p_male^2) + (p_female^2))
		
	histogram hhi_race if forprofit==1, frequency normal
	histogram hhi_gender if forprofit==1, frequency normal
	
	/*Still skewed, which has to do with there being many small companies with only 1 race or 1 gender.
	The benefit is that this measure does not put an artificial cap on the level of diversity.
	With this measure, the most diverse organization is one with an equal number of men and women 
	or whites and non-whites.*/
	
	
	reg sales hhi_race hhi_gender proprietorship partnership public_corporation private_corporation ///
		co es organization_age agriculture mining construction ///
		transportation wholesale retail financialserv businessserv personalserv entertainment ///
		professionalserv northeast midwest south if forprofit==1 
		eststo //annual sales revenue

	reg cu hhi_race hhi_gender proprietorship partnership public_corporation private_corporation ///
		co es organization_age agriculture mining construction ///
		transportation wholesale retail financialserv businessserv personalserv entertainment ///
		professionalserv northeast midwest south if forprofit==1 
		eststo //number of customers

	reg market hhi_race hhi_gender proprietorship partnership public_corporation private_corporation ///
		co es organization_age agriculture mining construction ///
		transportation wholesale retail financialserv businessserv personalserv entertainment ///
		professionalserv northeast midwest south if forprofit==1 
		eststo //market share

	reg profit hhi_race hhi_gender proprietorship partnership public_corporation private_corporation ///
		co es organization_age agriculture mining construction ///
		transportation wholesale retail financialserv businessserv personalserv entertainment ///
		professionalserv northeast midwest south if forprofit==1 
		eststo //profitability
		
	esttab, star(* 0.10 ** 0.05 *** 0.01)
	est drop *	
	
	/*Conclusion with the HHI-index: only a small effect for racial diversity on customers, all other
	effects are absent.*/
	
	
//K- Rerunning models with multiple imputation of missings

use "$pathd/nos1997.dta", clear
set more off

	//creating variables for imputation
	
		/*forprofit organizations*/
		recode a1 1=0 2=1, gen(forprofit) //0 missings
	
		* I. diversity: main independent variables
		
		* 1. Share of male employees

		/*total number ft female employees*/
		recode a7a_n -999 99999 88888=.

		/*total percent ft female employees*/
		recode a7a_p -999=.
		
		/*total ft employees on org payroll. We need this variable for calculating the percent of 
		ft female employees in those organizations that reported the number*/
		recode a7 -999 99999 88888=. 
		recode a7 0=., gen(a7_2)
		
		/*total percent ft female employees (2). here we calculate the % ft female employees in organizations that reported the number*/
		generate share_fem2=int(100*(a7a_n/a7_2))	
		/*total percent ft female employees*/
		replace a7a_p = share_fem2 if a7a_p==. //adding the % ft female emp for the businesses that reported the number
		tab a7a_p, m
		//*two businesses reported more female employees than total number of employees. We mark these as missing:
		replace a7a_p =. if a7a_p>100 //two to missing

		rename a7a_p share_fem 
		generate share_male=100-share_fem //final variable for use in analyses

		*2. Share of white employees
		/*organizations could choose to report either the number or the percentage of ft
		white employees. We combine these two into a single measure, as done above for gender*/

		/*total number ft white employees*/
        recode a7b_n -999 99999 88888=.

		/*total percent ft white employees*/
		recode a7b_p -999=.

		/*total percent ft white employees (2). here we calculate the % ft white employees in organizations that reported the number*/
		generate share_white2=int(100*(a7b_n/a7_2))

		/*total percent ft white employees*/
		replace a7b_p = share_white2 if a7b_p==. //adding the % ft white emp for the businesses that reported the number
		tab a7b_p, m
		//*five businesses reported more white employees than total number of employees. We mark these as missing:
		replace a7b_p =. if a7b_p>100 //five to missing
		
		rename a7b_p share_white //final variable for use in analyses
	
		* II. business performance: the four dependent variables

		*1. annual sales revenue
		recode o9 -999 88888888888 99999999999=., gen(sales)

		*2. number of customers
		recode o8 -999 88888888 99999999=., gen(customers)
		la var customers "number of customers past 2yrs"
		
		*3. market share
		recode o10b -999 6 7=., gen(market)
		la var market "perceived relative market share"

		*4. profitability
		recode o10a -999 6 7=., gen(profit)
		la var profit "perceived relative profitability"
		
		//transformations to address skew 
		
		replace sales=log(((sales+0.01)/1000000)) //sales
		la var sales "annual sales revenue past 2yrs"
	
		gen cu=ln(customers) //number of customers
		la var cu "Customers (natural logarithm)"
		
		* III. control variables

		*1. legal form of organization
		recode a1b -999 7 8=.
		recode a1b 1=1 2=2 3=5 4=3 5=4 6=5
			
		*2. establishment size 
		recode a9 -999 88888 99999=. //total pt employees on org payrol, 69 missings
		replace a9=0 if a9==. & !missing(a7) //enabling addition of ft and pt employees
		replace a7=0 if a7==. & !missing(a9) //enabling addition of ft and pt employees
		
		/*total ft and pt employees on org payrol*/ 
		generate establishment_size=a7+a9
		tab establishment_size //there are 16 businesses with 0 pt and ft employees; We treat these as missing:
		recode establishment_size 0=. 
		la var establishment_size "number of ft and pt employees on payroll"
		
		*3. company size   
		recode a3a3 -999 888888=.
		recode a3g -999 999999=. 888888=.
		generate company_size=a3a3 //adding the answers of the establishments that are headquarters
		replace company_size=establishment_size if company_size==. & a3==2 //if organization is independent, number is that of establishment
		replace company_size=a3g if company_size==. //adding the answers of the establishments that are part of larger org and not headquarters
		la var company_size "number of ft and pt employees at all locations"

		*4. organization age
		recode a2 -999 9999 8888=.
		generate organization_age=1997-a2
		la var organization_age "organization age"

		*5. industry
		tab a17 //0 missings
		
		*6. region
		tab state, m //121 missings; missing states: DE, AK, HI
		encode state, gen(region) //state is a string variable in the dataset
		recode region 6 17 19 28 29 32 36 37 44=1 10 12 13 14 20 21 22 26 27 33 34 39 46=2 ///
		1 2 7 8 9 15 16 18 23 25 38 40 41 43 47=3 3 4 5 11 24 30 31 35 42 45 48 =4
		label define regionl 1 "northeast" 2 "midwest" 3 "south" 4 "west"
		la val region regionl
		tab region, m 
		
		//transformations to address skew
		
		gen co=ln(company_size) //company size
		la var co "Company size (natural logarithm)"
	
		gen es=ln(establishment_size) //establishment size
		la var es "Establishment size (natural logarithm)"
		
	//keeping relevant variables 
		keep sales cu market profit share_white share_male a1b ///
					co es organization_age a17 region forprofit
					
	// keep for-profit organizations
		keep if forprofit == 1
					
	//number of missing observations per variable	
		misstable summarize 
		
	//imputation 
	
		*declaring the data as mi data
		mi set wide
		
		*checking missing data pattern 
		mi misstable nested //arbitrary
	
		*registering variables
		mi register imputed sales cu market profit share_white share_male ///
						co es organization_age region a1b //imputed vars 

		mi register regular a17 forprofit //regular vars that have the same values in all m
		
		*imputation
		
		mi fvset base 5 a1b
		mi fvset base 4 region
		
		mi impute chained (pmm, knn(5)) sales cu co es organization_age share_male share_white ///
			(ologit) market profit (mlogit) region a1b = a17 forprofit, add(20) rseed(2232) noisily augment
			//To lessen the simulation (Monte Carlo) error, we choose to create 20 imputations (add(20))			
							
		*verifying that nothing abnormal occurred during imputation
		//descriptive statistics for observed data and first and last imputation
		mi xeq 0 1 20: summarize sales cu market profit share_white share_male ///
					co es organization_age region a1b a17 forprofit
					
	//creating variables for analysis
		
		*legal form of organization	
		mi passive: generate proprietorship=0
		mi passive: replace proprietorship=1 if a1b==1 
		mi passive: generate partnership=0 
		mi passive: replace partnership=1 if a1b==2  
		mi passive: generate public_corporation=0
		mi passive: replace public_corporation=1 if a1b==3
		mi passive: generate private_corporation=0
		mi passive: replace private_corporation=1 if a1b==4
      
		*industry
		mi passive: generate agriculture=inrange(a17,10,32)
		mi passive: generate mining=inrange(a17,40,50)
		mi passive: generate construction=inrange(a17,60,60)
		mi passive: generate manufacturing=inrange(a17,100,392)
		mi passive: generate transportation=inrange(a17,400,472)
		mi passive: generate wholesale=inrange(a17,500,571)
		mi passive: generate retail=inrange(a17,580,691)
		mi passive: generate financialserv=inrange(a17,700,712)
		mi passive: generate businessserv=inrange(a17,721,760)
		mi passive: generate personalserv=inrange(a17,761,791)
		mi passive: generate entertainment=inrange(a17,800,810)
		mi passive: generate professionalserv=inrange(a17,812,893)
		
		*region		
		mi passive: generate northeast=0
		mi passive: replace northeast=1 if region==1 
		mi passive: generate midwest=0
		mi passive: replace midwest=1 if region==2
		mi passive: generate south=0
		mi passive: replace south=1 if region==3
		mi passive: generate west=0
		mi passive: replace west=1 if region==4

		*assymetrical index of diversity
		
			//Asymmetrical Index of Diversity for race (AID-R)
			/*AID-R = (1-Sw) if Sw>Pw; AID-R = (1-Pw) if Pw>=Sw*/
			mi estimate: mean share_white if !missing(share_white) //75%
			mi passive: generate aidr=(100-(share_white)) if share_white > 75
			mi passive: replace aidr=(100-75) if 75>=(share_white)
	
			//Asymmetrical Index of Diversity for gender (AID-G)
			/*AID-G = (1-Sm) if Sm>Pm; AID-G = (1-Pm) if Pm>=Sm*/
			mi estimate: mean share_male if !missing(share_male) //52%
			mi passive: generate aidg=100-share_male if share_male > 52
			mi passive: replace aidg=100-52 if 52>=share_male
			
			/*
			//Asymmetrical Index of Diversity for race (AID-R)
			/*AID-R = (1-Sw) if Sw>Pw; AID-R = (1-Pw) if Pw>=Sw*/
			mi estimate: mean share_white if !missing(share_white) //75%
			mi passive: generate aidr=(100-(share_white)) if share_white > r(mean)
			mi passive: replace aidr=(100-r(mean)) if r(mean)>=(share_white)
	
			//Asymmetrical Index of Diversity for gender (AID-G)
			/*AID-G = (1-Sm) if Sm>Pm; AID-G = (1-Pm) if Pm>=Sm*/
			mi estimate: mean share_male if !missing(share_male) //52%
			mi passive: generate aidg=100-share_male if share_male>r(mean)
			mi passive: replace aidg=100-r(mean) if r(mean)>=share_male		
			*/
		
	//saving imputed data
	
		save "$pathp/nos_imputeddata.dta", replace //saving imputed data for analysis	

	//analysis

		*1. annual sales revenue
		mi estimate: reg sales 	aidr aidg proprietorship partnership public_corporation private_corporation ///
					co es organization_age  agriculture mining construction ///
					transportation wholesale retail financialserv businessserv personalserv entertainment ///
					professionalserv northeast midwest south if forprofit==1 

		*2. number of customers 
		mi estimate: reg cu 	aidr aidg proprietorship partnership public_corporation private_corporation ///
				co es organization_age agriculture mining construction ///
				transportation wholesale retail financialserv businessserv personalserv entertainment ///
				professionalserv northeast midwest south if forprofit==1 

		*3. market share
		mi estimate: reg market 	aidr aidg proprietorship partnership public_corporation private_corporation ///
					co es organization_age agriculture mining construction ///
					transportation wholesale retail financialserv businessserv personalserv entertainment ///
					professionalserv northeast midwest south if forprofit==1 

		*4. profitability
		mi estimate: reg profit 	aidr aidg proprietorship partnership public_corporation private_corporation ///
					co es organization_age agriculture mining construction ///
					transportation wholesale retail financialserv businessserv personalserv entertainment ///
					professionalserv northeast midwest south if forprofit==1 
					
log close
