*==============================================================================*
*                              Description of dofile                           *
/*=============================================================================*
This dofile prepares the data for the results that are presented in the comment 
"Does Diversity Pay? A Replication of Herring (2009)." 
The structure of this dofile is as follows:
      
  
  1. Setting paths and installing ado-files
  2. Opening data 
  3. Data preparation
  4. Saving data
  

*==============================================================================*/
*    	   	   	  1. Setting paths and installing ado-files                    *
*==============================================================================*

** -- A. Downloading ado-files -- **
ssc install usespss, replace //works only in 32-bit Stata for Windows
ssc install distinct, replace


** -- B. Setting paths -- **
global dir "SET YOUR PATH"
  
global pathd "$dir/data"
global pathp "$dir/posted"
global patht "$dir/tables"
global pathf "$dir/figures"
global pathl "$dir/logfiles"

set more off
cap log close
log using "$pathl/dataprep.log", replace


*==============================================================================*
*                              2. Opening data                                 *
*==============================================================================*

/*
Data: National Organizations Survey (NOS), 1996-1997 (ICPSR 3190)                  
Retrieved from: http://www.icpsr.umich.edu/icpsrweb/DSDR/studies/3190, November 2015                                                                         

Herring states that "[t]he data come from the 1996 to 1997 National Organizations 
Survey (NOS) (Kalleberg, Knoke, and Marsden 2001), which contains information from 
1,002 U.S. work establishments, drawn from a stratified random sample of approximately
15 million work establishments in Dun and Bradstreet's Information Services data file" (p.213).

The same wording can be found in the codebook of the downloaded study: "The 1996-1997 NOS 
consists of data on 1,002 United States work establishments and was conducted from June 10,
1996, to June 13, 1997, using a stratified random sample from approximately 15 million work
establishments in Dun and Bradstreet's Information Services data file" (Codebook, n.d.).

The bibliographic citation for this data collection is:
Kalleberg, Arne L., David Knoke, and Peter V. Marsden. NATIONAL ORGANIZATIONS SURVEY (NOS),
1996-1997 [Computer file]. ICPSR version. Minneapolis, MN: University of Minnesota Center
for Survey Research [producer], 1997. Ann Arbor, MI: Inter-university Consortium for 
Political and Social Research [distributor], 2001. (Codebook, n.d.).

The same bibliographic citation is found in Herring (p.223).

The downloaded version (2001) is the first and last version of the 1996 to 1997 NOS (at the time of analysis, November 2015).

The NOS encourages users of this data to use the following disclaimer:
"The data (and tabulations) utilized in this (publication) were made available (in part)
by the archive or agency which distributed the data. The data for the 1996-1997
National Organizations Survey were originally collected by the Minnesota Center for
Survey Research at the University of Minnesota. Neither the original sources or
collectors of the data nor the distributor of the data bear any responsibility for the
analyses or interpretations presented herein."
*/



** -- A. data and sample size -- **

/*data is provided only in spss and sas format; we use stata*/
clear all
usespss "$pathd/03190-0001-Data.sav" //works only in 32-bit Stata for Windows
save "$pathd/nos1997.dta", replace

use "$pathd/nos1997.dta", clear

/*initial sample size*/ 
*ssc install distinct, replace
distinct orgid //1002 distinct organizations, confirming that this is the right data

*==============================================================================*
*                            3. Data preparation                               *
*==============================================================================*

** -- A. preparing the variables -- **
/*the codebook (n.d.) states that: "Although missing data codes were created by the 
principal investigators where appropriate, the archived version of the SPSS portable
file did not declare any of these values to be missing. Users should consult the codebook 
to determine which codes for which variables they wish to treat as missing values."

We have hence followed the codebook to declare missing values as missing. Missing values
initially take three different labels: NA (Not applicable), DK (Don't know), and RA (Refuse to answer). 
NA takes the value '-999'; DK and RA take varying values; DA takes for instance '888888' and '6'; RA '999999' and '7'.
In declaring missing values we check whether the number of missings in the dataset matches
that reported in the codebook. Unless specified otherwise below, this is the case.*/

	* I. diversity: main independent variables
	/*Herring measures gender and racial diversity distinctly but parallely with an
	own-constructed "Asymmetrical Index of Diversity (AID)" (p.214). 
	This index is based on the shares of white (race) and male (gender) full-time (p.213)
	employees, both recorded in the NOS data. We calculate the AID below.
	For now we prepare the base variables, that is, shares of male and white ft employees.*/
	
		* 1. Share of male employees
		/*organizations could choose to report either the number or the percentage of ft
		female employees. We combine these two into a single measure of the percentage of 
		ft female employees and finally calculate the percentage of ft male employees*/

		/*total number ft female employees*/
		recode a7a_n -999 99999 88888=.
		sum a7a_n //min 0, max 9582
		tab a7a_n, m //517 missings

		/*total percent ft female employees*/
		recode a7a_p -999=.
		sum a7a_p //min 3, max 100
		tab a7a_p, m //614 missings

			//are there businesses that reported both the number and the percent?
			tab a7a_n if !missing(a7a_p), m
			tab a7a_p if !missing(a7a_n), m //conclusion: no

		/*total ft employees on org payroll. We need this variable for calculating the percent of 
		ft female employees in those organizations that reported the number*/
		recode a7 -999 99999 88888=. 
		sum a7 //there are businesses with 0 ft employees. We declare these as missing in a new variable;
		//We keep a7 with the 0s for later (see below) when we calculate the size of the organization in number of full- and part-time employees
		recode a7 0=., gen(a7_2)
		sum a7_2 //min 1, max 42000
		tab a7_2, m //48 missings
		//concerns: there are 45 businesses with 1 employee; in these businesses there is 0 diversity; 
		//there is also 0 diversity in businesses with 100 employees out of which all are white/non-white or male/female. 
		//these two are not equivalent theoretically. See 'Additional Robustness Checks' in "analyses_main.do" where we address this issue. 
		
		/*total percent ft female employees (2). here we calculate the % ft female employees in organizations that reported the number*/
		generate share_fem2=int(100*(a7a_n/a7_2))	
		/*total percent ft female employees*/
		replace a7a_p = share_fem2 if a7a_p==. //adding the % ft female emp for the businesses that reported the number
		tab a7a_p, m
		//*two businesses reported more female employees than total number of employees. We mark these as missing:
		replace a7a_p =. if a7a_p>100 //two to missing
		sum a7a_p //min 0, max 100
		tab a7a_p, m //131 missings
		
		rename a7a_p share_fem 
		generate share_male=100-share_fem //final variable for use in analyses

		*2. Share of white employees
		/*organizations could choose to report either the number or the percentage of ft
		white employees. We combine these two into a single measure, as done above for gender*/

		/*total number ft white employees*/
        recode a7b_n -999 99999 88888=.
		sum a7b_n //min 0, max 12805
		tab a7b_n, m //592 missings

		/*total percent ft white employees*/
		recode a7b_p -999=.
		sum a7b_p //min 3, max 100
		tab a7b_p, m //584 missings

			//are there businesses that reported both the number and the percent?
			tab a7b_n if !missing(a7b_p), m
			tab a7b_p if !missing(a7b_n), m //conclusion: no

		/*total percent ft white employees (2). here we calculate the % ft white employees in organizations that reported the number*/
		generate share_white2=int(100*(a7b_n/a7_2))

		/*total percent ft white employees*/
		replace a7b_p = share_white2 if a7b_p==. //adding the % ft white emp for the businesses that reported the number
		tab a7b_p, m
		//*five businesses reported more white employees than total number of employees. We mark these as missing:
		replace a7b_p =. if a7b_p>100 //five to missing
		sum a7b_p //min 0, max 100
		tab a7b_p, m //179 missings
		
		rename a7b_p share_white //final variable for use in analyses

	* II. business performance: the four dependent variables

		*1. annual sales revenue
		/* measured with "What was your organization's average annual sales revenue for the past two years?" (Herring, p.214)*/
		recode o9 -999 88888888888 99999999999=., gen(sales)
		//generate sales=o9 //keeping untransformed (as below) sales
		sum sales //min 0, max 6.00e+10
		tab sales, m //620 missings
		generate sales2=sales //sales untransformed
		//concerns: there are 8 businesses with 0 sales revenue. See "Additional Robustness Checks" in "analyses_main.do". 
		/*Herring furthermore states: "For multivariate analysis, I add a small number (.01) to each observation before
		dividing it by 1 million and taking the log of these values." (p. 214). Hence, we do the same:*/
		replace sales=log(((sales+0.01)/1000000)) //final variable for use in analyses
		la var sales "annual sales revenue past 2yrs"

		*2. number of customers
		/* measured with "About how many customers purchased the organization's products or services over the past two years?"(Herring, p.214)*/
		recode o8 -999 88888888 99999999=., gen(customers)
		//clonevar customers = o8  //final variable for use in analyses
		la var customers "number of customers past 2yrs"
		sum customers //min 0, max 2.50e+07
		tab customers, m //583 missings
		//concerns: there are 5 businesses with 0 customers. See "Additional Robustness Checks" in "analyses_main.do". 

		*3. market share
		/* measured with "Compared to other organizations that do the same kind of work, how would you compare your organization's performance
		over the past two years in terms of market share? .|.|. Would you say that it was (1) much worse, (2) somewhat worse, 
		(3) about the same, (4) somewhat better, or (5) much better?" (Herring, p.214)*/
		recode o10b -999 6 7=., gen(market)
		//rename o10b market //final variable for use in analyses
		la var market "perceived relative market share"
		sum market //min 1, max 5, mean 3.62
		tab market, m //408 missings

		*4. profitability
		/* measured with "Compared to other organizations that do the same kind of work, how would you compare your organization's performance
		over the past two years in terms of profitability? .|.|. Would you say that it was (1) much worse, (2) somewhat worse,
		(3) about the same, (4) somewhat better, or (5) much better?" (Herring, p.214)*/
		recode o10a -999 6 7=., gen(profit)
		//rename o10a profit //final variable for use in analyses
		la var profit "perceived relative profitability"
		sum profit //min 1, max 5, mean 3.65
		tab profit, m //389 missings

	* III. control variables

		*1. legal form of organization
		/*measured with "What is the legal form of organization? Is it a sole proprietorship, partnership or limited partnership, franchise, 
		corporation with publicly held stock, corporation with privately held stock, or something else?"
	    Responses are dummy coded for proprietorship, partnership, franchise, and corporation. (Herring, p. 215).
		The form of legal organization is recorded as one variable. We make dummies from this variable*/
		recode a1b -999 7 8=.
		tab a1b, m //299 missings
		recode a1b 1=1 2 3 4 5 6=0, gen(proprietorship)
		tab proprietorship, m //299 missings
		la var proprietorship "organization is proprietorship"
		recode a1b 2=1 1 3 4 5 6=0, gen(partnership)
		tab partnership, m //299 missings
		la var partnership "organization is partnernship"
		recode a1b 3=1 1 2 4 5 6=0, gen(franchise)
		tab franchise, m //299 missings
		la var franchise "organization is franchise"
		recode a1b 4=1 1 2 3 5 6=0, gen(public_corporation)
		tab public_corporation, m //299 missings
		la var public_corporation "organization is public corporation"
		recode a1b 5=1 1 2 3 4 6=0, gen(private_corporation)
		tab private_corporation, m //299 missings
		la var private_corporation "organization is private corporation"
      
		*2. establishment size 
		/* Herring states: "respondents were also asked about the establishment size (i.e., the number of full-time and part-time employees on 
		the payroll at their particular address)." (p.215)
		The number of full- and part-time employees are recorded as separate variables. We add them for a total number of employees*/
		tab a7, m //total ft employees on org payrol, 22 missings (already recoded, see above)
		recode a9 -999 88888 99999=. //total pt employees on org payrol, 69 missings
		replace a9=0 if a9==. & !missing(a7) //enabling addition of ft and pt employees
		replace a7=0 if a7==. & !missing(a9) //enabling addition of ft and pt employees
		
		/*total ft and pt employees on org payrol*/ 
		generate establishment_size=a7+a9
		tab establishment_size //there are 16 businesses with 0 pt and ft employees; We treat these as missing:
		recode establishment_size 0=. 
		sum establishment_size //min 1, max 42000
		tab establishment_size, m //37 missings
		la var establishment_size "number of ft and pt employees on payroll"
		
		*3. company size   
		/* "respondents were asked about the number of full-time and part-time employees who work at all locations of the business". (Herring, p.215)
		Two relevant variables. First, a3a3=number of ft/pt emp at all locations, answered by establishments that are part of a larger company and headquarters. 
		Second, a3g=number of larger org ft/pt employees, answered by establishments that are part of a larger company and not headquarters.*/
		
		tab a3a3, m //988 missing, 14 valid answers. only 27 of the establishments are headquarters (see question A3a); 14 of them have answered this question.
		tab a3g, m //870 missing, 132 valid answers. out of the 284 establishments that are not headquarters, 132 of them answered this question.  
		//if the organization is independent (see question a3), the company size equals the establishment size. 685 orgs are completely independent.
		recode a3a3 -999 888888=.
		recode a3g -999 999999=. 888888=.
		generate company_size=a3a3 //adding the answers of the establishments that are headquarters
		replace company_size=establishment_size if company_size==. & a3==2 //if organization is independent, number is that of establishment
		replace company_size=a3g if company_size==. //adding the answers of the establishments that are part of larger org and not headquarters
		sum company_size //min 1, max 800000 (different in Herring who seems to have used only a3a3 (min 1, max 300000). 
		tab company_size, m  //199 missings
		la var company_size "number of ft and pt employees at all locations"

		*4. organization age
		/* "In what year did the organization start operations?" The difference between the year of the survey and the year of establishment
		yields the organization age (Herring, p.215)*/
		recode a2 -999 9999 8888=.
		generate organization_age=1997-a2
		sum organization_age //min 1, max 361
		tab organization_age, m //92 missings
		la var organization_age "organization age"

		*5. industry
		/* "respondents were asked about the main product or service provided at their establishments. Responses are dummy coded into the
		following 12 categories: agriculture; mining; construction; transportation and communications; wholesale; retail; financial services,
		insurance, and real estate; business services; personal services; entertainment; professional services; and manufacturing" (Herring, p.215).
		A single variable measuring industry code is provided in the data. Upon careful inspection, although not specified by Herring, we established
		that the industry code classification used is the 1990 Census Industry and Occupation Classification Systems*/
		tab a17 //0 missings
		recode a17 10/32=1 40/932=0, gen(agriculture)
			la var agriculture "industry is agriculture"
		recode a17 10/32=0 40/50=1 60/932=0, gen(mining)
			la var mining "industry is mining"
		recode a17 10/50=0 60=1 100/932=0, gen(construction)
			la var construction "industry is construction"
		recode a17 10/60=0 100/392=1 400/932=0, gen(manufacturing)
			la var manufacturing "industry is manufacturing"
		recode a17 10/392=0 400/472=1 450/932=0, gen(transportation)
			la var transportation "industry is transportation"
		recode a17 10/472=0 500/571=1 580/932=0, gen(wholesale)
			la var wholesale "industry is wholesale"
		recode a17 10/571=0 580/691=1 700/932=0, gen(retail)
			la var retail "industry is retail"
		recode a17 10/691=0 700/712=1 721/932=0, gen(financialserv)
			la var financialserv "industry is financial services" 
		recode a17 10/712=0 721/760=1 761/932=0, gen(businessserv)
			la var businessserv "industry is business services"
		recode a17 10/760=0 761/791=1 800/932=0, gen(personalserv)
			la var personalserv "industry is personal services"
		recode a17 10/791=0 800/810=1 812/932=0, gen(entertainment)
			la var entertainment "industry is entertainment"
		recode a17 10/810=0 812/893=1 900/932=0, gen(professionalserv)	
			la var professionalserv "industry is professional services"
		
		*6. region
		/* "The region in which the establishment is located is dummy coded into four categories: Northeast (CT, DE, MA, ME, 
		NH, NJ, NY, PA, RI, and VT), Midwest (IA, IL, IN, KS, MI, MN, MO, ND, NE, OH, OK, SD, and WI), South(AL, AR, DC, FL, 
		GA, KY, LA, MD, MS, NC, SC, TN, TX, VA, and WV), and West and others (AK, AZ, CA, CO, HI, ID, MT, NM, NV, OR, UT, WA, and WY)" (Herring, p.215).
		The dataset provides a variable recording the state where the establishment is located*/
		tab state, m //121 missings; missing states: DE, AK, HI
		encode state, gen(region) //state is a string variable in the dataset
		recode region 6 17 19 28 29 32 36 37 44=1 1 2 3	4 5	7 8	9 10 11	12 13 14 15 16 18 20 21 22 23 24 25 26 27 30 31 ///
		33 34 35 38 39 40 41 42 43 45 46 47 48=0 else=., gen(northeast)
		tab northeast, m //121 missings
		la var northeast "organization is located in northeast"
		tab state if northeast==1 //checking if recoding went well
		recode region 10 12 13 14 20 21 22 26 27 33 34 39 46=1 1 2 3 4 5 6 7 8 9 11 15 16 17 18 19 23 24 25 28 29 30 31 ///
		32 35 36 37 38 40 41 42 43 44 45 47 48=0 else=., gen(midwest)
		tab midwest, m //121 missings
		la var midwest "organization is located in midwest"
		tab state if midwest==1 //checking if recoding went well
		recode region 1 2 7 8 9 15 16 18 23 25 38 40 41 43 47=1 3 4 5 6 10 11 12 13 14 17 19 20 21	22 24 26 27 28 29 30 31	///
		32 33 34 35	36 37 39 42 44 45 46 48=0 else=., gen(south)
		tab south, m //121 missings
		la var south "organization is located in south"
		tab state if south==1 //checking if recoding went well
		recode region 3 4 5 11 24 30 31 35 42 45 48 =1 1 2 6 7 8 9 10 12 13	14 15 16 17	18 19 20 21	22 23 25 26	27 28 29 ///
		32 33 34 36	37 38 39 40	41 43 44 46 47=0 else=., gen(west)
		tab west, m //121 missings
		la var west "organization is located in west"
		tab state if west==1 //checking if recoding went well

** -- B. Sample selection -- **
/*Herring states that he uses "data from the 506 forprofit business organizations that provided
information about the racial composition of their full-time workforces, their sales revenue,
their number of customers, their market share, and their profitability" (p. 213).

Hence, the sample is based on six variables: 
	(1) only forprofit businesses
	(2) businesses for which the % of ft white employees is non-missing
	(3) businesses for which sales revenue is non-missing
	(4) businesses for which number of customers is non-missing
	(5) businesses for which market share is non-missing
	(6) businesses for which profitability is non-missing
	
While gender diversity is the other predictor of interest, next to racial diversity, Herring does not
state availability of information about gender composition as a criterion on which to base the sample.

We add a seventh criterion for constructing the sample size:
	(7) businesses for which the % of ft male employees is non-missing*/

** -- C. Calculating the Assymetrical Index of Diversity -- **
/*Herring calculates an Assymetrical Index of Diversity separately for race (AID-R) and gender (AID-G) using the formulae on page 214.

Following Herring, we calculate the Assymetrical Index of Diversity for race (AID-R) as follows:
AID-R = (1-Sw) if Sw>Pw
AID-R = (1-Pw) if Pw>=Sw, where

Sw is the proportion of the organization composed of whites ("superordinate group" (p.214))
Pw is the proportion of the population composed of whites (p.214)

Sw is thus the % whites in a particular forprofit business organization

Pw, as inferred from Herring, is the % whites in the "population in the 1996 to 1997 NOS" (p.214), i.e., the total average % whites in businesses
in the 1996-97 NOS. Hence, we also base the population average on the whole 1996 to 1997 NOS sample. The first step taken below is thus to 
calculate this "population" average. It could also be that since Herring wants to extrapolate to forprofit businesses, the population that he
refers to concerns only forprofit businesses. As shown below, however, using the whole sample, we come closer to Herring's figures
than by using a sample containing only forprofit businesses.

The Assymetrical Index of Diversity for gender (AID-G), parallel to what has been explained above is:
AID-G = (1-Sm) if Sm>Pm
AID-G = (1-Pm) if Pm>=Sm, where

Sm is the proportion of the organization composed of males 
Pm is the proportion of the population composed of males*/

	*1. Calculating the share of the superordinate groups in the population
	
	/*selecting only forprofit organizations*/
	codebook a1 // 292 Non-profit (1); 710 For profit (2); 0 missings 
	recode a1 1=0 2=1, gen(forprofit)
	tab forprofit, m

	/*what is the share of the superordinate racial group, i.e., whites in the population*?*/
	//"population" here is defined as the "population in the 1996 to 1997 NOS" (Herring, 2009, p.214)
	sum share_white if !missing(share_white) //mean is 76%; 75% in Herring (p.214)
	sum share_white if forprofit==1 & !missing(share_white) //looking only at for-profit businessses, mean is 76%;
	
	/*what is the share of the superordinate gender group, i.e., males in the population*?*/
	//"population" here is defined as the "population in the 1996 to 1997 NOS" (Herring, 2009, p.214)
	sum share_male if !missing(share_male) //mean is 52%; 54% in Herring (p.214)
	sum share_male if forprofit==1 & !missing(share_male) //looking only at for-profit businesses, mean is 57%;
	
	*2.Calculating the Asymmetrical Index of Diversity for race (AID-R)
	/*AID-R = (1-Sw) if Sw>Pw; AID-R = (1-Pw) if Pw>=Sw*/
	sum share_white if !missing(share_white) 
	generate aidr=(100-(share_white)) if share_white > r(mean)
	replace aidr=(100-r(mean)) if r(mean)>=(share_white)
	tab aidr //range: 0-24; In Herring, 0-25 (p.214)
	la var aidr "Assymetrical index of diversity for race"
	
	*3.Calculating the Asymmetrical Index of Diversity for gender (AID-G)
	/*AID-G = (1-Sm) if Sm>Pm; AID-G = (1-Pm) if Pm>=Sm*/
	sum share_male if !missing(share_male) 
	generate aidg=100-share_male if share_male>r(mean)
	replace aidg=100-r(mean) if r(mean)>=share_male
	tab aidg //range: 0-48; In Herring, 0-46 (p.214)
	la var aidg "Assymetrical index of diversity for gender" 


	
*==============================================================================*
*                              4. Saving data                                  *
*==============================================================================*	
save "$pathp/nos_workingdata.dta", replace //saving the data for analysis



log close
